"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = require("path");
var dirTree = require('directory-tree');
var util_1 = require("./util");
var TestFiles = /** @class */ (function () {
    function TestFiles(engine) {
        this.engine = engine;
        this.nodes = new Map();
    }
    TestFiles.prototype.read = function (path) {
        this.files = [];
        this.nodes.clear();
        var files = dirTree(path, {
            exclude: /node_modules|\.git/
        });
        this.files = this.transform(files) || [];
        return this.files;
    };
    TestFiles.prototype.getFiles = function () {
        return this.files;
    };
    TestFiles.prototype.transform = function (node, parent) {
        var _this = this;
        if (!node.children) {
            return;
        }
        var children = [];
        node.children.forEach(function (child) {
            var path = child.path;
            var treeNode;
            if (child.type === 'file' && !_this.engine.testMatcher(path)) {
                return null;
            }
            if (_this.nodes.get(path) && child.type === 'file') {
                treeNode = _this.nodes.get(path);
            }
            else {
                treeNode = _this.createFile(path, child);
            }
            if (!treeNode) {
                return null;
            }
            if ((child.type !== 'file' &&
                treeNode.children &&
                treeNode.children.length > 0) ||
                child.type === 'file') {
                children.push(treeNode);
            }
            if (child.type === 'file' && !_this.nodes.get(path)) {
                _this.nodes.set(path, treeNode);
            }
        });
        return children;
    };
    TestFiles.prototype.createFile = function (path, child) {
        var node = {
            label: path_1.basename(path),
            children: [],
            path: path,
            type: child.type,
            itBlocks: child.type === 'file' ? util_1.getItBlocks(path) : []
        };
        node.children = this.transform(child, node);
        return node;
    };
    return TestFiles;
}());
exports.default = TestFiles;
//# sourceMappingURL=TestFiles.js.map